argus_plugins — Argus-Toolbelt 1.0 documentation

# argus_plugins

- Argus Plugins
  - Creating a new plugin
    - Function metadata
    - Example #1: Registering a command
    - Example #2: Registering a command with extra functionality
  - Guides
    - Creating a simple plugin
    - Creating an API plugin
    - Logging from a plugin
  - Subpackages
    - argus_plugins.cases package
      - Submodules
      - argus_plugins.cases.remind module
      - argus_plugins.cases.utils module
      - Module contents
  - Submodules
  - argus_plugins.generate module
    - GENERATOR PLUGIN
  - Module contents